NLSL: mtsdef Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
mtsdef Module Reference

## Variables
integer, parameter | nlemx =1
integer, parameter | nlomx =2
integer, parameter | nkmn =3
integer, parameter | nkmx =4
integer, parameter | nmmn =5
integer, parameter | nmmx =6
integer, parameter | nipnmx =7
integer, parameter | nldel =8
integer, parameter | nkdel =9
integer, parameter | nipsi0 =10
integer, parameter | nin2 =11
integer, parameter | njkmn =12
integer, parameter | njmmn =13
integer, parameter | ntrc =7

## Variable Documentation

integer, parameter mtsdef::nin2 =11

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::nipnmx =7

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::nipsi0 =10

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::njkmn =12

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::njmmn =13

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::nkdel =9

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::nkmn =3

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::nkmx =4

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::nldel =8

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::nlemx =1

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::nlomx =2

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::nmmn =5

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::nmmx =6

Definition at line 29 of file mtsdef.f90.

integer, parameter mtsdef::ntrc =7

Definition at line 29 of file mtsdef.f90.